@@ -1635,8 +1635,45 @@ END
 
 };
 
+our $gnusocial_twitter_permissions=sub {
+
+   my $twitter_permission_banner=<<'END';
+     ___ _                         ___               _       _
+    / __| |_  __ _ _ _  __ _ ___  | _ \___ _ _ _ __ (_)_____(_)___ _ _  ___
+   | (__| ' \/ _` | ' \/ _` / -_) |  _/ -_) '_| '  \| (_-<_-< / _ \ ' \(_-<
+    \___|_||_\__,_|_||_\__, \___| |_| \___|_| |_|_|_|_/__/__/_\___/_||_/__/
+                       |___/
+
+END
+   $twitter_permission_banner.=<<END;
+   Back to twitter go to Permissions tab:      _____________
+                                              |             |
+   Details  Settings   Keys and Access Tokens | Permissions | 
+  ____________________________________________|             |______________
+ 
+   Click and change to the following Access setting, and click
+   [Update Settings] button at bottom of page.
+
+   (O)  Read, Write and Access direct messages
+
+    _________________
+   | Update Settings |
+   |_________________| 
+END
+   my $gnusocial_twitter_perms={
+
+      Name => 'gnusocial_twitter_perms',
+      Result => $gnusocial_setup_summary,
+      Banner => $twitter_permission_banner,
+
+   };
+   return $gnusocial_twitter_perms;
+
+};
+
 our $gnusocial_enter_twitter_api=sub {
 
+   package gnusocial_enter_twitter_api;
    my $twitter_api_banner=<<'END';
     ___     _             _  __             _     ___                 _
    | __|_ _| |_ ___ _ _  | |/ /___ _  _   _| |_  / __| ___ __ _ _ ___| |_
@@ -1665,7 +1702,8 @@ END
 
       Name => 'gnusocial_twitter_api',
       Input => 1,
-      Result => $gnusocial_setup_summary,
+      Result =>
+   $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_twitter_permissions,
       Banner => $twitter_api_banner,
 
    };
